@@ -13,9 +13,8 @@
   GNU General Public License for more details.
  
   You should have received a copy of the GNU General Public 
-  License along with this program; if not, write to the Free 
-  Software Foundation, Inc., 675 Massachusetss Ave, Cambridge, 
-  MA 02139, USA.
+  License along with this program;
+  If not, see <http://www.gnu.org/licenses/>.
  
   Corresponding concerning ESO-MIDAS should be addressed as follows:
 	Internet e-mail: midas@eso.org
