@@ -2,7 +2,7 @@
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
  * Copyright (C) 2012-2016 team free-astro (see more in AUTHORS file)
- * Reference site is http://free-astro.vinvin.tf/index.php/Siril
+ * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,6 +43,7 @@
 #include "gui/callbacks.h"
 #include "gui/PSF_list.h"
 #include "gui/histogram.h"
+#include "gui/plot.h"
 #include "algos/colors.h"
 #include "algos/PSF.h"
 #include "algos/star_finder.h"
@@ -118,7 +119,7 @@ command commande[] = {
 	{"mirrorx", 0, "mirrorx", process_mirrorx},
 	{"mirrory", 0, "mirrory", process_mirrory},
 	
-	{"new", 2, "new width height nb_layers", process_new},
+	{"new", 3, "new width height nb_layers", process_new},
 	{"nozero", 1, "nozero level (replaces null values by level)", process_nozero}, /* replaces null values by level */
 	
 	{"offset", 1, "offset value", process_offset},
@@ -154,6 +155,7 @@ command commande[] = {
 	{"setcpu", 1, "setcpu number", process_set_cpu},
 #endif
 	{"setmag", 1, "setmag magnitude", process_set_mag},
+	{"setmagseq", 1, "setmagseq magnitude", process_set_mag_seq},
 	{"split", 3, "split R G B", process_split},
 	{"stat", 0, "stat", process_stat},
 	{"stackall", 0, "stackall", process_stackall},
@@ -166,6 +168,7 @@ command commande[] = {
 	{"unselect", 2, "unselect from to", process_unselect},
 	{"unsharp", 2, "unsharp sigma multi", process_unsharp},
 	{"unsetmag", 0, "unsetmag", process_unset_mag},
+	{"unsetmagseq", 0, "unsetmagseq", process_unset_mag_seq},
 //	{"unsharp2", 5, "unsharp2 sigma multi src dest number", process_unsharp2},
 
 	{"visu", 2, "visu low high", process_visu},
@@ -671,9 +674,7 @@ int process_rotatepi(int nb){
 
 int process_set_mag(int nb) {
 	int layer = match_drawing_area_widget(com.vport[com.cvport], FALSE);
-	double mag;
-
-	mag = atof(word[1]);
+	double mag = atof(word[1]);
 
 	if (layer != -1) {
 
@@ -699,7 +700,37 @@ int process_set_mag(int nb) {
 
 int process_unset_mag(int nb) {
 	com.magOffset = 0.0;
+	return 0;
+}
 
+int process_set_mag_seq(int nb) {
+	if (!sequence_is_loaded()) {
+		siril_log_message(_("This command can be used only when a sequence is loaded\n"));
+		return 1;
+	}
+	double mag = atof(word[1]);
+	int i;
+	for (i = 0; i < MAX_SEQPSF && com.seq.photometry[i]; i++);
+	com.seq.reference_star = i-1;
+	if (i == 0) {
+		siril_log_message(_("Run a PSF for the sequence first (see seqpsf)\n"));
+		return 1;
+	}
+	com.seq.reference_mag = mag;
+	siril_log_message(_("Reference magnitude has been set for star %d to %f and will be computed for each image\n"), i-1, mag);
+	drawPlot();
+	return 0;
+}
+
+int process_unset_mag_seq(int nb) {
+	if (!sequence_is_loaded()) {
+		siril_log_message(_("This command can be used only when a sequence is loaded\n"));
+		return 1;
+	}
+	com.seq.reference_star = -1;
+	com.seq.reference_mag = -1001.0;
+	siril_log_message(_("Reference magnitude unset for sequence\n"));
+	drawPlot();
 	return 0;
 }
 
@@ -724,10 +755,19 @@ int process_psf(int nb){
 	return 0;
 }
 
+gboolean end_seqpsf(gpointer arg) {
+	set_layers_for_registration();	// update display of available reg data
+	if (com.seq.needs_saving)
+		writeseqfile(&com.seq);
+	drawPlot();
+	notify_new_photometry();
+	return end_generic(arg);
+}
+
 void *_psf_thread(void *arg) {
 	int layer = (intptr_t) arg;
-	do_fwhm_sequence_processing(&com.seq, layer, TRUE, TRUE, TRUE);
-	gdk_threads_add_idle(end_generic, NULL);
+	do_fwhm_sequence_processing(&com.seq, layer, TRUE, TRUE, TRUE, FALSE);
+	gdk_threads_add_idle(end_seqpsf, NULL);
 	return NULL;
 }
 
@@ -1337,9 +1377,9 @@ int process_split(int nb){
 		siril_log_message(_("Siril cannot split layers. Make sure your image is in RGB mode.\n"));
 		return 1;
 	}
-	sprintf(R, "%s.fit", word[1]);
-	sprintf(G, "%s.fit", word[2]);
-	sprintf(B, "%s.fit", word[3]);
+	sprintf(R, "%s%s", word[1], com.ext);
+	sprintf(G, "%s%s", word[2], com.ext);
+	sprintf(B, "%s%s", word[3], com.ext);
 	save1fits16(R, &gfit, RLAYER);
 	save1fits16(G, &gfit, GLAYER);
 	save1fits16(B, &gfit, BLAYER);
@@ -1351,7 +1391,12 @@ int process_stat(int nb){
 	int layer;
 
 	for (layer = 0; layer < nplane; layer++) {
-		imstats* stat = statistics(&gfit, layer, &com.selection, STATS_MAIN);
+		imstats* stat = statistics(&gfit, layer, &com.selection, STATS_MAIN,
+		STATS_ZERO_NULLCHECK);
+		if (!stat) {
+			siril_log_message(_("Error: no data computed.\n"));
+			return 1;
+		}
 		siril_log_message(
 				_("%s layer: Mean: %0.1lf, Median: %0.1lf, Sigma: %0.1lf, "
 						"AvgDev: %0.1lf, Min: %0.1lf, Max: %0.1lf\n"),
@@ -1388,8 +1433,10 @@ gpointer stackall_worker(gpointer args) {
 				args.seq = seq;
 				args.filtering_criterion = stack_filter_all;
 				args.nb_images_to_stack = seq->number;
-				snprintf(filename, 256, "%s%sstacked.fit", seq->seqname,
-						ends_with(seq->seqname, "_") ? "" : "_");
+				snprintf(filename, 256, "%s%sstacked%s", seq->seqname,
+						ends_with(seq->seqname, "_") ?
+								"" : (ends_with(com.seq.seqname, "-") ? "" : "_"),
+						com.ext);
 				gettimeofday(&args.t_start, NULL);
 
 				retval = stack_summing(&args);
@@ -1429,7 +1476,9 @@ int process_set_cpu(int nb){
 	}
 	omp_set_num_threads(proc_in);
 
+#ifdef _OPENMP
 #pragma omp parallel
+#endif
 	{
 		proc_out = omp_get_num_threads();
 	}
