@@ -2,7 +2,7 @@
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
  * Copyright (C) 2012-2016 team free-astro (see more in AUTHORS file)
- * Reference site is http://free-astro.vinvin.tf/index.php/Siril
+ * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,6 +50,109 @@ static char *Exposure[] = { "EXPTIME", "EXPOSURE", NULL };
 	} while ((keyword[__iter__]) && (__status__ > 0)); \
 }
 
+/* reading the FITS header to get useful information */
+static void read_fits_header(fits *fit) {
+	/* about the status argument: http://heasarc.gsfc.nasa.gov/fitsio/c/c_user/node28.html */
+	int status = 0;
+	int zero;
+
+	__tryToFindKeywords(fit->fptr, TUSHORT, MIPSHI, &fit->hi);
+	__tryToFindKeywords(fit->fptr, TUSHORT, MIPSLO, &fit->lo);
+
+	status = 0;
+	fits_read_key(fit->fptr, TINT, "BSCALE", &zero, NULL, &status);
+	if (!status && 1 != zero)
+		siril_log_message(
+				_("Loaded FITS file has a BSCALE different than 1 (%d)\n"), zero);
+	status = 0;
+	fits_read_key(fit->fptr, TINT, "BZERO", &zero, NULL, &status);
+
+	if (fit->bitpix == SHORT_IMG && zero == 32768)
+		fit->bitpix = USHORT_IMG;
+
+	/*******************************************************************
+	 * ************* CAMERA AND INSTRUMENT KEYWORDS ********************
+	 * ****************************************************************/
+
+	__tryToFindKeywords(fit->fptr, TFLOAT, PixSizeX, &fit->pixel_size_x);
+	__tryToFindKeywords(fit->fptr, TFLOAT, PixSizeY, &fit->pixel_size_y);
+	__tryToFindKeywords(fit->fptr, TUINT, BinX, &fit->binning_x);
+	if (fit->binning_x <= 0) fit->binning_x = 1;
+	__tryToFindKeywords(fit->fptr, TUINT, BinY, &fit->binning_y);
+	if (fit->binning_y <= 0) fit->binning_y = 1;
+
+	status = 0;
+	fits_read_key(fit->fptr, TSTRING, "INSTRUME", &(fit->instrume), NULL,
+			&status);
+
+	status = 0;
+	fits_read_key(fit->fptr, TSTRING, "TELESCOP", &(fit->telescop), NULL,
+			&status);
+
+	status = 0;
+	fits_read_key(fit->fptr, TSTRING, "OBSERVER", &(fit->observer), NULL,
+			&status);
+
+	status = 0;
+	fits_read_key(fit->fptr, TSTRING, "BAYERPAT", &(fit->bayer_pattern), NULL,
+			&status);
+
+	status = 0;
+	fits_read_key(fit->fptr, TSTRING, "DATE-OBS", &(fit->date_obs), NULL,
+			&status);
+
+	status = 0;
+	fits_read_key(fit->fptr, TSTRING, "DATE", &(fit->date), NULL,
+			&status);
+
+	__tryToFindKeywords(fit->fptr, TDOUBLE, Focal, &fit->focal_length);
+	if (!sequence_is_loaded() || com.seq.current == 0)
+		fprintf(stdout,
+				"Read from FITS header: pix size %gx%g, binning %ux%u, focal %g\n",
+				fit->pixel_size_x, fit->pixel_size_y, fit->binning_x,
+				fit->binning_y, fit->focal_length);
+
+	status = 0;
+	fits_read_key(fit->fptr, TDOUBLE, "CCD-TEMP", &(fit->ccd_temp), NULL,
+			&status);	// Non-standard keywords used in MaxIm DL
+
+	__tryToFindKeywords(fit->fptr, TDOUBLE, Exposure, &fit->exposure);
+
+	status = 0;
+	fits_read_key(fit->fptr, TDOUBLE, "APERTURE", &(fit->aperture), NULL,
+			&status);
+
+	status = 0;
+	fits_read_key(fit->fptr, TDOUBLE, "ISOSPEED", &(fit->iso_speed), NULL,
+			&status);	// Non-standard keywords used in MaxIm DL
+
+	/*******************************************************************
+	 * ************************* DFT KEYWORDS **************************
+	 * ****************************************************************/
+
+	status = 0;
+	fits_read_key(fit->fptr, TDOUBLE, "DFT_NOR0", &(fit->dft_norm[0]), NULL,
+			&status);
+	status = 0;
+	fits_read_key(fit->fptr, TDOUBLE, "DFT_NOR1", &(fit->dft_norm[1]), NULL,
+			&status);
+	status = 0;
+	fits_read_key(fit->fptr, TDOUBLE, "DFT_NOR2", &(fit->dft_norm[2]), NULL,
+			&status);
+
+	status = 0;
+	fits_read_key(fit->fptr, TSTRING, "DFT_ORD", &(fit->dft_ord), NULL,
+			&status);
+
+	status = 0;
+	fits_read_key(fit->fptr, TSTRING, "DFT_TYPE", &(fit->dft_type), NULL,
+			&status);
+
+	status = 0;
+	fits_read_key(fit->fptr, TUSHORT, "DFT_RX", &(fit->dft_rx), NULL, &status);
+	fits_read_key(fit->fptr, TUSHORT, "DFT_RY", &(fit->dft_ry), NULL, &status);
+}
+
 // return 0 on success, fills realname if not NULL with the opened file's name
 int readfits(const char *filename, fits *fit, char *realname) {
 	int status;
@@ -256,103 +359,6 @@ int readfits(const char *filename, fits *fit, char *realname) {
 	return 0;
 }
 
-/* reading the FITS header to get useful information */
-void read_fits_header(fits *fit) {
-	/* about the status argument: http://heasarc.gsfc.nasa.gov/fitsio/c/c_user/node28.html */
-	int status = 0;
-	int zero;
-
-	__tryToFindKeywords(fit->fptr, TUSHORT, MIPSHI, &fit->hi);
-	__tryToFindKeywords(fit->fptr, TUSHORT, MIPSLO, &fit->lo);
-
-	status = 0;
-	fits_read_key(fit->fptr, TINT, "BSCALE", &zero, NULL, &status);
-	if (!status && 1 != zero)
-		siril_log_message(
-				_("Loaded FITS file has a BSCALE different than 1 (%d)\n"), zero);
-	status = 0;
-	fits_read_key(fit->fptr, TINT, "BZERO", &zero, NULL, &status);
-
-	if (fit->bitpix == SHORT_IMG && zero == 32768)
-		fit->bitpix = USHORT_IMG;
-
-	/*******************************************************************
-	 * ************* CAMERA AND INSTRUMENT KEYWORDS ********************
-	 * ****************************************************************/
-
-	__tryToFindKeywords(fit->fptr, TFLOAT, PixSizeX, &fit->pixel_size_x);
-	__tryToFindKeywords(fit->fptr, TFLOAT, PixSizeY, &fit->pixel_size_y);
-	__tryToFindKeywords(fit->fptr, TUINT, BinX, &fit->binning_x);
-	__tryToFindKeywords(fit->fptr, TUINT, BinY, &fit->binning_y);
-
-	status = 0;
-	fits_read_key(fit->fptr, TSTRING, "INSTRUME", &(fit->instrume), NULL,
-			&status);
-
-	status = 0;
-	fits_read_key(fit->fptr, TSTRING, "TELESCOP", &(fit->telescop), NULL,
-			&status);
-
-	status = 0;
-	fits_read_key(fit->fptr, TSTRING, "OBSERVER", &(fit->observer), NULL,
-			&status);
-
-	status = 0;
-	fits_read_key(fit->fptr, TSTRING, "DATE-OBS", &(fit->date_obs), NULL,
-			&status);
-
-	status = 0;
-	fits_read_key(fit->fptr, TSTRING, "DATE", &(fit->date), NULL,
-			&status);
-
-	__tryToFindKeywords(fit->fptr, TDOUBLE, Focal, &fit->focal_length);
-	if (!sequence_is_loaded() || com.seq.current == 0)
-		fprintf(stdout,
-				"Read from FITS header: pix size %gx%g, binning %ux%u, focal %g\n",
-				fit->pixel_size_x, fit->pixel_size_y, fit->binning_x,
-				fit->binning_y, fit->focal_length);
-
-	status = 0;
-	fits_read_key(fit->fptr, TDOUBLE, "CCD-TEMP", &(fit->ccd_temp), NULL,
-			&status);	// Non-standard keywords used in MaxIm DL
-
-	__tryToFindKeywords(fit->fptr, TDOUBLE, Exposure, &fit->exposure);
-
-	status = 0;
-	fits_read_key(fit->fptr, TDOUBLE, "APERTURE", &(fit->aperture), NULL,
-			&status);
-
-	status = 0;
-	fits_read_key(fit->fptr, TDOUBLE, "ISOSPEED", &(fit->iso_speed), NULL,
-			&status);	// Non-standard keywords used in MaxIm DL
-
-	/*******************************************************************
-	 * ************************* DFT KEYWORDS **************************
-	 * ****************************************************************/
-
-	status = 0;
-	fits_read_key(fit->fptr, TDOUBLE, "DFT_NOR0", &(fit->dft_norm[0]), NULL,
-			&status);
-	status = 0;
-	fits_read_key(fit->fptr, TDOUBLE, "DFT_NOR1", &(fit->dft_norm[1]), NULL,
-			&status);
-	status = 0;
-	fits_read_key(fit->fptr, TDOUBLE, "DFT_NOR2", &(fit->dft_norm[2]), NULL,
-			&status);
-
-	status = 0;
-	fits_read_key(fit->fptr, TSTRING, "DFT_ORD", &(fit->dft_ord), NULL,
-			&status);
-
-	status = 0;
-	fits_read_key(fit->fptr, TSTRING, "DFT_TYPE", &(fit->dft_type), NULL,
-			&status);
-
-	status = 0;
-	fits_read_key(fit->fptr, TUSHORT, "DFT_RX", &(fit->dft_rx), NULL, &status);
-	fits_read_key(fit->fptr, TUSHORT, "DFT_RY", &(fit->dft_ry), NULL, &status);
-}
-
 char *list_header(fits *fit) {
 	int status = 0;
 	int i, hdupos, nkeys, strsize, strlength;
@@ -671,6 +677,7 @@ int savefits(const char *name, fits *f) {
 void save_fits_header(fits *fit) {
 	int i, status = 0;
 	int zero;
+	unsigned int offset = 0;
 	char comment[FLEN_COMMENT];
 
 	if (fit->hi) { /* may not be initialized */
@@ -770,9 +777,18 @@ void save_fits_header(fits *fit) {
 				"ISO camera setting", &status);
 
 	status = 0;
-	if (fit->instrume[0] != '\0')
-		fits_update_key(fit->fptr, TSTRING, "INSTRUME", &(fit->instrume),
-				"instrument name", &status);
+	if (fit->bayer_pattern[0] != '\0') {
+		fits_update_key(fit->fptr, TSTRING, "BAYERPAT", &(fit->bayer_pattern),
+				"Bayer color pattern", &status);
+
+		status = 0;
+		fits_update_key(fit->fptr, TUINT, "XBAYROFF", &(offset),
+				"X offset of Bayer array", &status);
+
+		status = 0;
+		fits_update_key(fit->fptr, TUINT, "YBAYROFF", &(offset),
+				"Y offset of Bayer array", &status);
+	}
 
 	/*******************************************************************
 	 * ******************** PROGRAMM KEYWORDS **************************
@@ -1134,6 +1150,10 @@ int new_fit_image(fits *fit, int width, int height, int nblayer) {
 			fit->pdata[GLAYER] = fit->data + npixels;
 			fit->pdata[BLAYER] = fit->data + npixels * 2;
 		}
+		else {
+			fit->pdata[GLAYER] = fit->data;
+			fit->pdata[BLAYER] = fit->data;
+		}
 		return 0;
 	} else
 		return 1;
