@@ -2,7 +2,7 @@
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
  * Copyright (C) 2012-2016 team free-astro (see more in AUTHORS file)
- * Reference site is http://free-astro.vinvin.tf/index.php/Siril
+ * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,9 +42,6 @@
 #ifdef HAVE_LIBRAW
 #include <libraw/libraw.h>
 #endif
-#ifdef HAVE_LIBGIF
-#include <gif_lib.h>
-#endif
 
 #include "core/siril.h"
 #include "core/proto.h"
@@ -727,9 +724,11 @@ int readraw(const char *name, fits *fit) {
 			siril_log_message(_("AHD interpolation...\n"));
 			break;
 	}
+
 	
 	width = raw->sizes.iwidth;
 	height = raw->sizes.iheight;
+
 	npixels = width * height;
 	
 	data = malloc(npixels * sizeof(WORD) * 3);
@@ -778,42 +777,57 @@ int readraw(const char *name, fits *fit) {
 		*buf[BLAYER]++ = (image->data[i+4]) + (image->data[i+5] << 8);
 	}
 
-	libraw_dcraw_clear_mem(image);
-	libraw_recycle(raw);
-	libraw_close(raw);	
+	/*  Here we compute the correct size of the output image (imgdata.sizes.iwidth and imgdata.sizes.iheight) for the following cases:
+    	- Files from Fuji cameras (with a 45-degree rotation)
+    	- Files from cameras with non-square pixels
+    	- Images shot by a rotated camera.
+	 */
+	libraw_adjust_sizes_info_only(raw);
+	width = raw->sizes.iwidth;
+	height = raw->sizes.iheight;
 	
 	if (data != NULL) {
 		clearfits(fit);
 		fit->bitpix = USHORT_IMG;
-		fit->rx = width;
-		fit->ry = height;
-		fit->naxes[0] = width;
-		fit->naxes[1] = height;
+		fit->rx = (unsigned int) width;
+		fit->ry = (unsigned int) height;
+		fit->naxes[0] = (long) width;
+		fit->naxes[1] = (long) height;
 		fit->naxes[2] = nbplanes;
-		if (nbplanes==1)
+		if (nbplanes == 1)
 			fit->naxis = 2;
 		else
 			fit->naxis = 3;	
 		fit->data = data;
-		fit->pdata[RLAYER]=fit->data;
-		fit->pdata[GLAYER]=fit->data + npixels;
-		fit->pdata[BLAYER]=fit->data + npixels * 2;
-		fit->binning_x=fit->binning_y=1;
-		if (raw->other.focal_len>0.) fit->focal_length=raw->other.focal_len;
-		if (raw->other.iso_speed>0.) fit->iso_speed=raw->other.iso_speed;
-		if (raw->other.shutter>0.) fit->exposure=raw->other.shutter;
-		if (raw->other.aperture>0.) fit->aperture=raw->other.aperture;
-		snprintf(fit->instrume, FLEN_VALUE, "%s %s", raw->idata.make, raw->idata.model);
+		fit->pdata[RLAYER] = fit->data;
+		fit->pdata[GLAYER] = fit->data + npixels;
+		fit->pdata[BLAYER] = fit->data + npixels * 2;
+		fit->binning_x = fit->binning_y = 1;
+		if (raw->other.focal_len > 0.) fit->focal_length = raw->other.focal_len;
+		if (raw->other.iso_speed > 0.) fit->iso_speed = raw->other.iso_speed;
+		if (raw->other.shutter > 0.) fit->exposure = raw->other.shutter;
+		if (raw->other.aperture > 0.) fit->aperture = raw->other.aperture;
+		g_snprintf(fit->instrume, FLEN_VALUE, "%s %s", raw->idata.make, raw->idata.model);
 	}
+
+	libraw_dcraw_clear_mem(image);
+	libraw_recycle(raw);
+	libraw_close(raw);
+
 	return nbplanes;
 }
 
+#define FC(filters, row,col) \
+	(filters >> ((((row) << 1 & 14) + ((col) & 1)) << 1) & 3)
+
 int readraw_in_cfa(const char *name, fits *fit) {
 	libraw_data_t *raw = libraw_init(0);
-	unsigned int i, col, row;
-	ushort raw_width, width, height, left_margin, top_margin;
+	unsigned int i, j, c, col, row;
+	char pattern[FLEN_VALUE];
+	ushort raw_width, raw_height, left_margin, top_margin;
+	ushort width, height;
 	int npixels;
-	WORD *data=NULL;
+	WORD *data = NULL;
 	int ret = libraw_open_file(raw, name);
 	
 	if (ret) {
@@ -826,64 +840,115 @@ int readraw_in_cfa(const char *name, fits *fit) {
 		printf("Error in libraw %s\n", libraw_strerror(ret));
 		return -1;
 	}
-	
+
 	/* This test checks if raw data exist. Sometimes it doesn't. This is
 	 * the case for DNG built from lightroom for example */
-	if ((void*)raw->rawdata.raw_image != raw->rawdata.raw_alloc || raw->rawdata.raw_alloc == 0x00){
-		siril_log_message(_("Siril cannot open this file in CFA mode (no data available). Try to switch into RGB.\n"));
+	if ((void*) raw->rawdata.raw_image == 0x00
+			&& (raw->rawdata.color3_image || raw->rawdata.color4_image)) {
+		siril_log_message(_("Siril cannot open this file in CFA mode (no data available). "
+				"Try to switch into RGB.\n"));
 		return -1;
 	}
-		
+
 	raw->params.user_flip = 0;				/* no flip                                 */
 	raw->params.output_color = 0;			/* output colorspace, 0=raw, 1=sRGB, 2=Adobe, 3=Wide, 4=ProPhoto, 5=XYZ*/
 
 	raw_width = raw->sizes.raw_width;
-	width = raw->sizes.width;
-	height = raw->sizes.height;
-	npixels = width * height;	
+	raw_height = raw->sizes.raw_height;
+
 	left_margin = raw->rawdata.sizes.left_margin;
 	top_margin = raw->rawdata.sizes.top_margin;
+
+	if (raw->rawdata.ioparams.fuji_width) {
+		ushort right_margin = raw_width - raw->rawdata.ioparams.fuji_width
+				- left_margin;
+		width = raw_width - right_margin;
+		height = raw_height;
+	}
+	else {
+		width = raw->sizes.iwidth;
+		height = raw->sizes.iheight;
+	}
+
+	npixels = width * height;
 	
-	if (raw->other.shutter > 1.0)
-		siril_log_message(_("Decoding %s %s file (ISO=%g, Exposure=%gs)\n"),
-				raw->idata.make, raw->idata.model, raw->other.iso_speed, raw->other.shutter);
+	if (raw->other.shutter > 0 && raw->other.shutter < 1)
+		siril_log_message(_("Decoding %s %s file (ISO=%g, Exposure=1/%0.1f sec)\n"),
+						raw->idata.make, raw->idata.model, raw->other.iso_speed, 1/raw->other.shutter);
 	else
-		siril_log_message(_("Decoding %s %s file (ISO=%g, Exposure=1/%gs)\n"),
-				raw->idata.make, raw->idata.model, raw->other.iso_speed, 1/raw->other.shutter);
+		siril_log_message(_("Decoding %s %s file (ISO=%g, Exposure=%0.1f sec)\n"),
+						raw->idata.make, raw->idata.model, raw->other.iso_speed, raw->other.shutter);
+
+	unsigned filters = raw->idata.filters;
+
+	if (filters) {
+		int fhigh = 2, fwide = 2;
+		if ((filters ^ (filters >> 8)) & 0xff)
+			fhigh = 4;
+		if ((filters ^ (filters >> 16)) & 0xffff)
+			fhigh = 8;
+		if ((filters == 1) /* Leaf Catchlight with 16x16 bayer matrix */
+				|| (filters == 9)) /* Fuji X-Trans (6x6 matrix) */ {
+			siril_log_message(_("This kind of RAW pictures is not supported.\n"));
+			libraw_recycle(raw);
+			libraw_close(raw);
+			return -1;
+		}
+
+		j = 0;
+		for (i = 0; i < fhigh; i++) {
+			for (c = i && 0; c < fwide; c++) {
+				pattern[j++] = raw->idata.cdesc[FC(filters, i, c)];
+			}
+		}
+		pattern[j++] = '\0';
+		siril_log_message(_("Bayer pattern: %s\n"), pattern);
+	}
 
 	data = (WORD*) calloc(1, npixels * sizeof(WORD));
 	if (!data) {
+		libraw_recycle(raw);
+		libraw_close(raw);
 		return -1;
 	}
+
 	WORD *buf = data;
-	
-	int offset = raw_width * top_margin + left_margin;	
+
+	int offset = raw_width * top_margin + left_margin;
+
 	i = 0;
-	for (row = 0; row < height; row++){
-		for (col = 0; col < width; col++){
-			buf[i++] = (WORD)raw->rawdata.raw_image[offset + col + (raw_width * row)] ;
+	for (row = 0; row < height; row++) {
+		for (col = 0; col < width; col++) {
+			buf[i++] = raw->rawdata.raw_image[offset + col + (raw_width * row)];
 		}
 	}
-
+	
 	if (data != NULL) {
 		clearfits(fit);
 		fit->bitpix = USHORT_IMG;
-		fit->rx = (unsigned int) width;
-		fit->ry = (unsigned int) height;
-		fit->naxes[0] = (long) width;
-		fit->naxes[1] = (long) height;
+		fit->rx = (unsigned int) (width);
+		fit->ry = (unsigned int) (height);
+		fit->naxes[0] = (long) (width);
+		fit->naxes[1] = (long) (height);
 		fit->naxes[2] = 1;
 		fit->naxis = 2;
 		fit->data = data;
-		fit->pdata[RLAYER]=fit->data;
-		fit->pdata[GLAYER]=fit->data;
-		fit->pdata[BLAYER]=fit->data;
-		fit->binning_x=fit->binning_y=1;
-		if (raw->other.focal_len>0.) fit->focal_length=raw->other.focal_len;
-		if (raw->other.iso_speed>0.) fit->iso_speed=raw->other.iso_speed;
-		if (raw->other.shutter>0.) fit->exposure=raw->other.shutter;
-		if (raw->other.aperture>0.) fit->aperture=raw->other.aperture;
-		snprintf(fit->instrume, FLEN_VALUE, "%s %s", raw->idata.make, raw->idata.model);
+		fit->pdata[RLAYER] = fit->data;
+		fit->pdata[GLAYER] = fit->data;
+		fit->pdata[BLAYER] = fit->data;
+		fit->binning_x = fit->binning_y = 1;
+		if (raw->other.focal_len > 0.)
+			fit->focal_length = raw->other.focal_len;
+		if (raw->other.iso_speed > 0.)
+			fit->iso_speed = raw->other.iso_speed;
+		if (raw->other.shutter > 0.)
+			fit->exposure = raw->other.shutter;
+		if (raw->other.aperture > 0.)
+			fit->aperture = raw->other.aperture;
+		g_snprintf(fit->instrume, FLEN_VALUE, "%s %s", raw->idata.make,
+				raw->idata.model);
+		if (filters)
+			g_snprintf(fit->bayer_pattern, FLEN_VALUE, "%s", pattern);
 	}
 
 	libraw_recycle(raw);
@@ -903,264 +968,15 @@ int open_raw_files(const char *name, fits *fit, int type) {
 			retvalue = readraw_in_cfa(name, fit);
 			break;
 	}
-	mirrorx(fit, FALSE);
-	char *basename = g_path_get_basename(name);
-	siril_log_message(_("Reading RAW: file %s, %ld layer(s), %ux%u pixels\n"),
-						basename, fit->naxes[2], fit->rx, fit->ry);
-	g_free(basename);
+	if (retvalue >= 0) {
+		mirrorx(fit, FALSE);
+		char *basename = g_path_get_basename(name);
+		siril_log_message(
+				_("Reading RAW: file %s, %ld layer(s), %ux%u pixels\n"),
+				basename, fit->naxes[2], fit->rx, fit->ry);
+		g_free(basename);
+	}
 
 	return retvalue;
 }
 #endif
-
-
-/********************* GIF EXPORT *********************/
-#ifdef HAVE_LIBGIF
-
-/* save a fit as gif.
- * If anim is true, if gif is nul, it is set to the created GIF handle. If it's
- * not nul it's used as is and a new image is added to the GIF.
- * If an error occurs, everything is freed and the file may be closed, in that
- * case, gif is set to NULL.
- * No check is done on filename actually corresponding to gif.
- * if anim, gif must be finalized with gifclose(gif).
- * if positive, delay and loop_count are used for animation. Delay is in centiseconds.
- *
- * palette code inspired by https://github.com/schani/animatedgif/blob/master/writegif.c
- */
-int savegif(const char *filename, fits *fit, int anim, GifFileType **gif, int delay, int loop_count) {
-	/* convert the fits to RGB 8-bit buffers, using the min/max scale */
-	BYTE *rgb[3];
-	BYTE map[USHRT_MAX + 1];
-	GifByteType *gif_buffer;
-	WORD tmp_pixel_value, hi, lo;
-	int i, nb_pixels;
-	float pente;
-
-	if (anim && gif == NULL) {
-		printf("Gif should not be NULL in anim mode\n");
-		return 1;
-	}
-
-	nb_pixels = fit->rx * fit->ry;
-	if (fit->naxes[2] == 1) {
-		/*  gif_buffer contains values of the palette, which in our case of
-		 *  linear grey palette are the same as the pixel values */
-		gif_buffer = malloc(nb_pixels);
-		if (!gif_buffer) {
-			printf("Failed to allocate memory required, aborted.\n");
-			return 1;
-		}
-	} else {
-		assert(fit->naxes[2] == 3);
-		gif_buffer = NULL;
-
-		rgb[0] = malloc(nb_pixels);
-		if (rgb[0] == NULL) {
-			printf("Failed to allocate memory required, aborted.\n");
-			if (anim) *gif = NULL;
-			return 1;
-		}
-		rgb[1] = malloc(nb_pixels);
-		if (rgb[1] == NULL) {
-			printf("Failed to allocate memory required, aborted.\n");
-			if (anim) *gif = NULL;
-			return 1;
-		}
-		rgb[2] = malloc(nb_pixels);
-		if (rgb[2] == NULL) {
-			printf("Failed to allocate memory required, aborted.\n");
-			if (anim) *gif = NULL;
-			return 1;
-		}
-	}
-
-	pente = computePente(&lo, &hi);
-	
-	for (i = 0; i <= USHRT_MAX; i++) {
-		map[i] = round_to_BYTE((float) i * pente);
-		if (map[i] == UCHAR_MAX)
-			break;
-	}
-	if (i != USHRT_MAX + 1) {
-		/* no more computation needed, just fill with max value */
-		for (++i; i <= USHRT_MAX; i++)
-			map[i] = UCHAR_MAX;
-	}
-	
-	/* doing the WORD to BYTE conversion, bottom-up */
-	if (fit->naxes[2] == 1) {
-		int x, y;
-		WORD *src = fit->data;
-		BYTE *dst = gif_buffer;
-		for (y = 0; y < fit->ry; y++) {
-			int desty = fit->ry - y - 1;
-			int srcpixel = y * fit->rx;
-			int dstpixel = desty * fit->rx;
-			for (x = 0; x < fit->rx; x++, srcpixel++, dstpixel++) {
-				// linear scaling
-				tmp_pixel_value = src[srcpixel] - lo;
-				dst[dstpixel] = map[tmp_pixel_value];
-			}
-		}
-	} else {
-		int channel;
-		for (channel = 0; channel < 3; channel++) {
-			int x, y;
-			WORD *src = fit->pdata[channel];
-			BYTE *dst = rgb[channel];
-			for (y = 0; y < fit->ry; y++) {
-				int desty = fit->ry-y-1;
-				int srcpixel = y * fit->rx;
-				int dstpixel = desty * fit->rx;
-				for (x = 0; x < fit->rx; x++, srcpixel++, dstpixel++) {
-					// linear scaling
-					if (src[srcpixel] - lo < 0)
-						tmp_pixel_value = 0;
-					else 	tmp_pixel_value = src[srcpixel] - lo;
-					dst[dstpixel] = map[tmp_pixel_value];
-				}
-			}
-		}
-	}
-
-	/* transform to GIF data */
-	ColorMapObject *OutputColorMap = NULL;
-	int ColorMapSize = 256;
-
-	if (fit->naxes[2] == 1) {
-		GifColorType gif_colors[256];	// the palette (a.k.a. color map)
-		for (i = 0; i < 256; i++) {
-			gif_colors[i].Red = gif_colors[i].Green = gif_colors[i].Blue = i;
-		}
-
-		if ((OutputColorMap = GifMakeMapObject(ColorMapSize, gif_colors)) == NULL) {
-			free(gif_buffer);
-			printf("Failed to allocate memory required, aborted.\n");
-			if (anim) *gif = NULL;
-			return 1;
-		}
-	} else {
-
-		if ((OutputColorMap = GifMakeMapObject(ColorMapSize, NULL)) == NULL ||
-				(gif_buffer = malloc(nb_pixels * sizeof(GifByteType))) == NULL) {
-			free(rgb[0]); free(rgb[1]); free(rgb[2]);
-			printf("Failed to allocate memory required, aborted.\n");
-			if (anim) *gif = NULL;
-			return 1;
-		}
-
-		if (GifQuantizeBuffer(fit->rx, fit->ry, &ColorMapSize,
-					rgb[0], rgb[1], rgb[2],
-					gif_buffer, OutputColorMap->Colors) == GIF_ERROR) {
-			free(rgb[0]); free(rgb[1]); free(rgb[2]); free(gif_buffer);
-			siril_log_message(_("Failed to convert data into GIF data format\n"));
-			if (anim) *gif = NULL;
-			GifFreeMapObject(OutputColorMap);
-			return 1;
-		}
-
-		free(rgb[0]); free(rgb[1]); free(rgb[2]);
-	}
-
-	/*********** code from SaveGif function **********/
-	int error;
-	GifFileType *GifFile;
-	if (!anim || *gif == NULL) {
-		if ((GifFile = EGifOpenFileName(filename, FALSE, &error)) == NULL) {
-			siril_log_message(_("Error opening GIF file: %s\n"), GifErrorString(error));
-			free(gif_buffer);
-			GifFreeMapObject(OutputColorMap);
-			return 1;
-		}
-
-		if (EGifPutScreenDesc(GifFile, fit->rx, fit->ry, 256, 0, OutputColorMap) == GIF_ERROR) {
-			siril_log_message(_("Error describing GIF file: %s\n"), GifErrorString(error));
-			EGifCloseFile(GifFile, NULL);
-			free(gif_buffer);
-			GifFreeMapObject(OutputColorMap);
-			return 1;
-		}
-
-		if (EGifPutComment(GifFile, "Made with Siril, for free astronomy") == GIF_ERROR) {
-			siril_log_message(_("Error adding comment in GIF file\n"));
-		}
-
-		/* add loop, optional */
-		if (anim && loop_count > 0) {
-			char nsle[12] = "NETSCAPE2.0";
-			char subblock[3];
-			subblock[0] = 1;
-			subblock[1] = loop_count / 256;
-			subblock[2] = loop_count % 256;
-			if (EGifPutExtensionLeader(GifFile, APPLICATION_EXT_FUNC_CODE) == GIF_ERROR ||
-					EGifPutExtensionBlock(GifFile, 11, nsle) == GIF_ERROR ||
-					EGifPutExtensionBlock(GifFile, 3, subblock) == GIF_ERROR ||
-					EGifPutExtensionTrailer(GifFile) == GIF_ERROR) {
-				siril_log_message(_("Error adding the loop in GIF file\n"));
-			}
-		}
-	} else {
-		GifFile = *gif;
-	}
-
-	/* for each image */
-
-	/* add delay, optional */
-	if (anim && delay > 0) {
-		unsigned char ExtStr[4] = { 0x04, 0x00, 0x00, 0xff };
-		ExtStr[1] = delay % 256;
-		ExtStr[2] = delay / 256;
-		if (EGifPutExtension(GifFile, GRAPHICS_EXT_FUNC_CODE, 4, ExtStr) == GIF_ERROR) {
-			siril_log_message(_("Error adding the delay in GIF file\n"));
-		}
-	}
-
-	if (EGifPutImageDesc(GifFile, 0, 0, fit->rx, fit->ry, FALSE, OutputColorMap) == GIF_ERROR) {
-		siril_log_message(_("Error describing GIF file: %s\n"), GifErrorString(error));
-		EGifCloseFile(GifFile, NULL);
-		free(gif_buffer);
-		if (anim) *gif = NULL;
-		GifFreeMapObject(OutputColorMap);
-		return 1;
-	}
-
-	GifByteType *ptr = gif_buffer;
-	for (i = 0; i < fit->ry; i++) {
-		if (EGifPutLine(GifFile, ptr, fit->rx) == GIF_ERROR) {
-			EGifCloseFile(GifFile, NULL);
-			free(gif_buffer);
-			if (anim) *gif = NULL;
-			GifFreeMapObject(OutputColorMap);
-			return 1;
-		}
-		ptr += fit->rx;
-	}
-	/* end of for each image */
-
-	free(gif_buffer);
-	GifFreeMapObject(OutputColorMap);
-
-	if (!anim) {
-		if (EGifCloseFile(GifFile, &error) == GIF_ERROR) {
-			siril_log_message(_("Error closing GIF file: %s\n"), GifErrorString(error));
-			return 1;
-		}
-	} else {
-		*gif = GifFile;
-	}
-	return 0;
-}
-
-void closegif(GifFileType **gif) {
-	int error;
-	if (gif == NULL || *gif == NULL)
-		return;
-
-	if (EGifCloseFile(*gif, &error) == GIF_ERROR) {
-		siril_log_message(_("Error closing GIF file: %s\n"), GifErrorString(error));
-	}
-	*gif = NULL;
-}
-#endif
-
